// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pm

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	svr "LAPP_LF_MOM_BACKEND/services/pm"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Interface Name           : RegisterRoutes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 注册路由
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterRoutes() {
	// 模块pm路由分组
	grmi.RegisterRouteMapping("/pm", func(party router.Party) {

		// Asset的路由组
		asset := party.Party("/asset")
		// Asset的服务实例
		var serviceOfAsset = svr.NewAssetService()
		// Asset插入一条
		// RegisterInsertOneAsset(asset, "/insertone", serviceOfAsset.InsertOne)
		// Asset插入多条
		// RegisterInsertAsset(asset, "/insert", serviceOfAsset.Insert)
		// Asset删除一条
		// RegisterDeleteOneAsset(asset, "/deleteone", serviceOfAsset.DeleteOne)
		// Asset删除多条
		// RegisterDeleteAsset(asset, "/delete", serviceOfAsset.Delete)
		// Asset查询多条
		RegisterSelectAsset(asset, "/query", serviceOfAsset.Select)
		// Asset查询一条
		RegisterSelectOneAsset(asset, "/get", serviceOfAsset.SelectOne)
		// Asset修改一条
		// RegisterUpdateOneAsset(asset, "/updateone", serviceOfAsset.UpdateOne)
		// Asset修改多条
		// RegisterUpdateAsset(asset, "/update", serviceOfAsset.Update)

		// AssetKpi的路由组
		assetkpi := party.Party("/assetkpi")
		// AssetKpi的服务实例
		var serviceOfAssetKpi = svr.NewAssetKpiService()
		// AssetKpi插入一条
		// RegisterInsertOneAssetKpi(assetkpi, "/insertone", serviceOfAssetKpi.InsertOne)
		// AssetKpi插入多条
		// RegisterInsertAssetKpi(assetkpi, "/insert", serviceOfAssetKpi.Insert)
		// AssetKpi删除一条
		// RegisterDeleteOneAssetKpi(assetkpi, "/deleteone", serviceOfAssetKpi.DeleteOne)
		// AssetKpi删除多条
		// RegisterDeleteAssetKpi(assetkpi, "/delete", serviceOfAssetKpi.Delete)
		// AssetKpi查询多条
		RegisterSelectAssetKpi(assetkpi, "/query", serviceOfAssetKpi.Select)
		// AssetKpi查询一条
		RegisterSelectOneAssetKpi(assetkpi, "/get", serviceOfAssetKpi.SelectOne)
		// AssetKpi修改一条
		// RegisterUpdateOneAssetKpi(assetkpi, "/updateone", serviceOfAssetKpi.UpdateOne)
		// AssetKpi修改多条
		// RegisterUpdateAssetKpi(assetkpi, "/update", serviceOfAssetKpi.Update)

		// AssetTemplateLst的路由组
		assettemplatelst := party.Party("/assettemplatelst")
		// AssetTemplateLst的服务实例
		var serviceOfAssetTemplateLst = svr.NewAssetTemplateLstService()
		// AssetTemplateLst插入一条
		// RegisterInsertOneAssetTemplateLst(assettemplatelst, "/insertone", serviceOfAssetTemplateLst.InsertOne)
		// AssetTemplateLst插入多条
		// RegisterInsertAssetTemplateLst(assettemplatelst, "/insert", serviceOfAssetTemplateLst.Insert)
		// AssetTemplateLst删除一条
		// RegisterDeleteOneAssetTemplateLst(assettemplatelst, "/deleteone", serviceOfAssetTemplateLst.DeleteOne)
		// AssetTemplateLst删除多条
		// RegisterDeleteAssetTemplateLst(assettemplatelst, "/delete", serviceOfAssetTemplateLst.Delete)
		// AssetTemplateLst查询多条
		RegisterSelectAssetTemplateLst(assettemplatelst, "/query", serviceOfAssetTemplateLst.Select)
		// AssetTemplateLst查询一条
		RegisterSelectOneAssetTemplateLst(assettemplatelst, "/get", serviceOfAssetTemplateLst.SelectOne)
		// AssetTemplateLst修改一条
		// RegisterUpdateOneAssetTemplateLst(assettemplatelst, "/updateone", serviceOfAssetTemplateLst.UpdateOne)
		// AssetTemplateLst修改多条
		// RegisterUpdateAssetTemplateLst(assettemplatelst, "/update", serviceOfAssetTemplateLst.Update)

		// AssetType的路由组
		assettype := party.Party("/assettype")
		// AssetType的服务实例
		var serviceOfAssetType = svr.NewAssetTypeService()
		// AssetType插入一条
		// RegisterInsertOneAssetType(assettype, "/insertone", serviceOfAssetType.InsertOne)
		// AssetType插入多条
		// RegisterInsertAssetType(assettype, "/insert", serviceOfAssetType.Insert)
		// AssetType删除一条
		// RegisterDeleteOneAssetType(assettype, "/deleteone", serviceOfAssetType.DeleteOne)
		// AssetType删除多条
		// RegisterDeleteAssetType(assettype, "/delete", serviceOfAssetType.Delete)
		// AssetType查询多条
		RegisterSelectAssetType(assettype, "/query", serviceOfAssetType.Select)
		// AssetType查询一条
		RegisterSelectOneAssetType(assettype, "/get", serviceOfAssetType.SelectOne)
		// AssetType修改一条
		// RegisterUpdateOneAssetType(assettype, "/updateone", serviceOfAssetType.UpdateOne)
		// AssetType修改多条
		// RegisterUpdateAssetType(assettype, "/update", serviceOfAssetType.Update)

		// Attribute的路由组
		attribute := party.Party("/attribute")
		// Attribute的服务实例
		var serviceOfAttribute = svr.NewAttributeService()
		// Attribute插入一条
		// RegisterInsertOneAttribute(attribute, "/insertone", serviceOfAttribute.InsertOne)
		// Attribute插入多条
		// RegisterInsertAttribute(attribute, "/insert", serviceOfAttribute.Insert)
		// Attribute删除一条
		// RegisterDeleteOneAttribute(attribute, "/deleteone", serviceOfAttribute.DeleteOne)
		// Attribute删除多条
		// RegisterDeleteAttribute(attribute, "/delete", serviceOfAttribute.Delete)
		// Attribute查询多条
		RegisterSelectAttribute(attribute, "/query", serviceOfAttribute.Select)
		// Attribute查询一条
		RegisterSelectOneAttribute(attribute, "/get", serviceOfAttribute.SelectOne)
		// Attribute修改一条
		// RegisterUpdateOneAttribute(attribute, "/updateone", serviceOfAttribute.UpdateOne)
		// Attribute修改多条
		// RegisterUpdateAttribute(attribute, "/update", serviceOfAttribute.Update)

		// AttributeValst的路由组
		attributevalst := party.Party("/attributevalst")
		// AttributeValst的服务实例
		var serviceOfAttributeValst = svr.NewAttributeValstService()
		// AttributeValst插入一条
		// RegisterInsertOneAttributeValst(attributevalst, "/insertone", serviceOfAttributeValst.InsertOne)
		// AttributeValst插入多条
		// RegisterInsertAttributeValst(attributevalst, "/insert", serviceOfAttributeValst.Insert)
		// AttributeValst删除一条
		// RegisterDeleteOneAttributeValst(attributevalst, "/deleteone", serviceOfAttributeValst.DeleteOne)
		// AttributeValst删除多条
		// RegisterDeleteAttributeValst(attributevalst, "/delete", serviceOfAttributeValst.Delete)
		// AttributeValst查询多条
		RegisterSelectAttributeValst(attributevalst, "/query", serviceOfAttributeValst.Select)
		// AttributeValst查询一条
		RegisterSelectOneAttributeValst(attributevalst, "/get", serviceOfAttributeValst.SelectOne)
		// AttributeValst修改一条
		// RegisterUpdateOneAttributeValst(attributevalst, "/updateone", serviceOfAttributeValst.UpdateOne)
		// AttributeValst修改多条
		// RegisterUpdateAttributeValst(attributevalst, "/update", serviceOfAttributeValst.Update)

		// Location的路由组
		location := party.Party("/location")
		// Location的服务实例
		var serviceOfLocation = svr.NewLocationService()
		// Location插入一条
		// RegisterInsertOneLocation(location, "/insertone", serviceOfLocation.InsertOne)
		// Location插入多条
		// RegisterInsertLocation(location, "/insert", serviceOfLocation.Insert)
		// Location删除一条
		// RegisterDeleteOneLocation(location, "/deleteone", serviceOfLocation.DeleteOne)
		// Location删除多条
		// RegisterDeleteLocation(location, "/delete", serviceOfLocation.Delete)
		// Location查询多条
		RegisterSelectLocation(location, "/query", serviceOfLocation.Select)
		// Location查询一条
		RegisterSelectOneLocation(location, "/get", serviceOfLocation.SelectOne)
		// Location修改一条
		// RegisterUpdateOneLocation(location, "/updateone", serviceOfLocation.UpdateOne)
		// Location修改多条
		// RegisterUpdateLocation(location, "/update", serviceOfLocation.Update)

		// Service的路由组
		service := party.Party("/service")
		// Service的服务实例
		var serviceOfService = svr.NewServiceService()
		// Service插入一条
		// RegisterInsertOneService(service, "/insertone", serviceOfService.InsertOne)
		// Service插入多条
		// RegisterInsertService(service, "/insert", serviceOfService.Insert)
		// Service删除一条
		// RegisterDeleteOneService(service, "/deleteone", serviceOfService.DeleteOne)
		// Service删除多条
		// RegisterDeleteService(service, "/delete", serviceOfService.Delete)
		// Service查询多条
		RegisterSelectService(service, "/query", serviceOfService.Select)
		// Service查询一条
		RegisterSelectOneService(service, "/get", serviceOfService.SelectOne)
		// Service修改一条
		// RegisterUpdateOneService(service, "/updateone", serviceOfService.UpdateOne)
		// Service修改多条
		// RegisterUpdateService(service, "/update", serviceOfService.Update)

		// ServiceAttrLst的路由组
		serviceattrlst := party.Party("/serviceattrlst")
		// ServiceAttrLst的服务实例
		var serviceOfServiceAttrLst = svr.NewServiceAttrLstService()
		// ServiceAttrLst插入一条
		// RegisterInsertOneServiceAttrLst(serviceattrlst, "/insertone", serviceOfServiceAttrLst.InsertOne)
		// ServiceAttrLst插入多条
		// RegisterInsertServiceAttrLst(serviceattrlst, "/insert", serviceOfServiceAttrLst.Insert)
		// ServiceAttrLst删除一条
		// RegisterDeleteOneServiceAttrLst(serviceattrlst, "/deleteone", serviceOfServiceAttrLst.DeleteOne)
		// ServiceAttrLst删除多条
		// RegisterDeleteServiceAttrLst(serviceattrlst, "/delete", serviceOfServiceAttrLst.Delete)
		// ServiceAttrLst查询多条
		RegisterSelectServiceAttrLst(serviceattrlst, "/query", serviceOfServiceAttrLst.Select)
		// ServiceAttrLst查询一条
		RegisterSelectOneServiceAttrLst(serviceattrlst, "/get", serviceOfServiceAttrLst.SelectOne)
		// ServiceAttrLst修改一条
		// RegisterUpdateOneServiceAttrLst(serviceattrlst, "/updateone", serviceOfServiceAttrLst.UpdateOne)
		// ServiceAttrLst修改多条
		// RegisterUpdateServiceAttrLst(serviceattrlst, "/update", serviceOfServiceAttrLst.Update)

		// Template的路由组
		template := party.Party("/template")
		// Template的服务实例
		var serviceOfTemplate = svr.NewTemplateService()
		// Template插入一条
		// RegisterInsertOneTemplate(template, "/insertone", serviceOfTemplate.InsertOne)
		// Template插入多条
		// RegisterInsertTemplate(template, "/insert", serviceOfTemplate.Insert)
		// Template删除一条
		// RegisterDeleteOneTemplate(template, "/deleteone", serviceOfTemplate.DeleteOne)
		// Template删除多条
		// RegisterDeleteTemplate(template, "/delete", serviceOfTemplate.Delete)
		// Template查询多条
		RegisterSelectTemplate(template, "/query", serviceOfTemplate.Select)
		// Template查询一条
		RegisterSelectOneTemplate(template, "/get", serviceOfTemplate.SelectOne)
		// Template修改一条
		// RegisterUpdateOneTemplate(template, "/updateone", serviceOfTemplate.UpdateOne)
		// Template修改多条
		// RegisterUpdateTemplate(template, "/update", serviceOfTemplate.Update)

		// TemplateServiceLst的路由组
		templateservicelst := party.Party("/templateservicelst")
		// TemplateServiceLst的服务实例
		var serviceOfTemplateServiceLst = svr.NewTemplateServiceLstService()
		// TemplateServiceLst插入一条
		// RegisterInsertOneTemplateServiceLst(templateservicelst, "/insertone", serviceOfTemplateServiceLst.InsertOne)
		// TemplateServiceLst插入多条
		// RegisterInsertTemplateServiceLst(templateservicelst, "/insert", serviceOfTemplateServiceLst.Insert)
		// TemplateServiceLst删除一条
		// RegisterDeleteOneTemplateServiceLst(templateservicelst, "/deleteone", serviceOfTemplateServiceLst.DeleteOne)
		// TemplateServiceLst删除多条
		// RegisterDeleteTemplateServiceLst(templateservicelst, "/delete", serviceOfTemplateServiceLst.Delete)
		// TemplateServiceLst查询多条
		RegisterSelectTemplateServiceLst(templateservicelst, "/query", serviceOfTemplateServiceLst.Select)
		// TemplateServiceLst查询一条
		RegisterSelectOneTemplateServiceLst(templateservicelst, "/get", serviceOfTemplateServiceLst.SelectOne)
		// TemplateServiceLst修改一条
		// RegisterUpdateOneTemplateServiceLst(templateservicelst, "/updateone", serviceOfTemplateServiceLst.UpdateOne)
		// TemplateServiceLst修改多条
		// RegisterUpdateTemplateServiceLst(templateservicelst, "/update", serviceOfTemplateServiceLst.Update)

		// UserServiceLst的路由组
		userservicelst := party.Party("/userservicelst")
		// UserServiceLst的服务实例
		var serviceOfUserServiceLst = svr.NewUserServiceLstService()
		// UserServiceLst插入一条
		// RegisterInsertOneUserServiceLst(userservicelst, "/insertone", serviceOfUserServiceLst.InsertOne)
		// UserServiceLst插入多条
		RegisterInsertUserServiceLst(userservicelst, "/insert", serviceOfUserServiceLst.Insert)
		// UserServiceLst删除一条
		// RegisterDeleteOneUserServiceLst(userservicelst, "/deleteone", serviceOfUserServiceLst.DeleteOne)
		// UserServiceLst删除多条
		// RegisterDeleteUserServiceLst(userservicelst, "/delete", serviceOfUserServiceLst.Delete)
		// UserServiceLst查询多条
		RegisterSelectUserServiceLst(userservicelst, "/query", serviceOfUserServiceLst.Select)
		// UserServiceLst查询一条
		//RegisterSelectOneUserServiceLst(userservicelst, "/get", serviceOfUserServiceLst.SelectOne)
		// UserServiceLst修改一条
		// RegisterUpdateOneUserServiceLst(userservicelst, "/updateone", serviceOfUserServiceLst.UpdateOne)
		// UserServiceLst修改多条
		// RegisterUpdateUserServiceLst(userservicelst, "/update", serviceOfUserServiceLst.Update)

		// UserAssetLst的路由组
		userassetlst := party.Party("/userassetlst")
		// UserAssetLst的服务实例
		var serviceOfUserAssetLst = svr.NewUserAssetLstService()
		// UserAssetLst插入一条
		// RegisterInsertOneUserAssetLst(userassetlst, "/insertone", serviceOfUserAssetLst.InsertOne)
		// UserAssetLst插入多条
		RegisterInsertUserAssetLst(userassetlst, "/insert", serviceOfUserAssetLst.Insert)
		// UserAssetLst删除一条
		// RegisterDeleteOneUserAssetLst(userassetlst, "/deleteone", serviceOfUserAssetLst.DeleteOne)
		// UserAssetLst删除多条
		// RegisterDeleteUserAssetLst(userassetlst, "/delete", serviceOfUserAssetLst.Delete)
		// UserAssetLst查询多条
		RegisterSelectUserAssetLst(userassetlst, "/query", serviceOfUserAssetLst.Select)
		// UserAssetLst查询一条
		//RegisterSelectOneUserAssetLst(userassetlst, "/get", serviceOfUserAssetLst.SelectOne)
		// UserAssetLst修改一条
		// RegisterUpdateOneUserAssetLst(userassetlst, "/updateone", serviceOfUserAssetLst.UpdateOne)
		// UserAssetLst修改多条
		// RegisterUpdateUserAssetLst(userassetlst, "/update", serviceOfUserAssetLst.Update)

		// WorkOrder的路由组
		workorder := party.Party("/workorder")
		// WorkOrder的服务实例
		var serviceOfWorkOrder = svr.NewWorkOrderService()
		// WorkOrder插入一条
		// RegisterInsertOneWorkOrder(workorder, "/insertone", serviceOfWorkOrder.InsertOne)
		// WorkOrder插入多条
		// RegisterInsertWorkOrder(workorder, "/insert", serviceOfWorkOrder.Insert)
		// WorkOrder删除一条
		// RegisterDeleteOneWorkOrder(workorder, "/deleteone", serviceOfWorkOrder.DeleteOne)
		// WorkOrder删除多条
		// RegisterDeleteWorkOrder(workorder, "/delete", serviceOfWorkOrder.Delete)
		// WorkOrder查询多条
		RegisterSelectWorkOrder(workorder, "/query", serviceOfWorkOrder.Select)
		// WorkOrder查询一条
		RegisterSelectOneWorkOrder(workorder, "/get", serviceOfWorkOrder.SelectOne)
		// WorkOrder修改一条
		// RegisterUpdateOneWorkOrder(workorder, "/updateone", serviceOfWorkOrder.UpdateOne)
		// WorkOrder修改多条
		// RegisterUpdateWorkOrder(workorder, "/update", serviceOfWorkOrder.Update)

		// WorkOrderAttrLst的路由组
		workorderattrlst := party.Party("/workorderattrlst")
		// WorkOrderAttrLst的服务实例
		var serviceOfWorkOrderAttrLst = svr.NewWorkOrderAttrLstService()
		// WorkOrderAttrLst插入一条
		// RegisterInsertOneWorkOrderAttrLst(workorderattrlst, "/insertone", serviceOfWorkOrderAttrLst.InsertOne)
		// WorkOrderAttrLst插入多条
		// RegisterInsertWorkOrderAttrLst(workorderattrlst, "/insert", serviceOfWorkOrderAttrLst.Insert)
		// WorkOrderAttrLst删除一条
		// RegisterDeleteOneWorkOrderAttrLst(workorderattrlst, "/deleteone", serviceOfWorkOrderAttrLst.DeleteOne)
		// WorkOrderAttrLst删除多条
		// RegisterDeleteWorkOrderAttrLst(workorderattrlst, "/delete", serviceOfWorkOrderAttrLst.Delete)
		// WorkOrderAttrLst查询多条
		RegisterSelectWorkOrderAttrLst(workorderattrlst, "/query", serviceOfWorkOrderAttrLst.Select)
		// WorkOrderAttrLst查询一条
		RegisterSelectOneWorkOrderAttrLst(workorderattrlst, "/get", serviceOfWorkOrderAttrLst.SelectOne)
		// WorkOrderAttrLst修改一条
		// RegisterUpdateOneWorkOrderAttrLst(workorderattrlst, "/updateone", serviceOfWorkOrderAttrLst.UpdateOne)
		// WorkOrderAttrLst修改多条
		// RegisterUpdateWorkOrderAttrLst(workorderattrlst, "/update", serviceOfWorkOrderAttrLst.Update)

		// WorkOrderNoteLst的路由组
		workordernotelst := party.Party("/workordernotelst")
		// WorkOrderNoteLst的服务实例
		var serviceOfWorkOrderNoteLst = svr.NewWorkOrderNoteLstService()
		// WorkOrderNoteLst插入一条
		// RegisterInsertOneWorkOrderNoteLst(workordernotelst, "/insertone", serviceOfWorkOrderNoteLst.InsertOne)
		// WorkOrderNoteLst插入多条
		// RegisterInsertWorkOrderNoteLst(workordernotelst, "/insert", serviceOfWorkOrderNoteLst.Insert)
		// WorkOrderNoteLst删除一条
		// RegisterDeleteOneWorkOrderNoteLst(workordernotelst, "/deleteone", serviceOfWorkOrderNoteLst.DeleteOne)
		// WorkOrderNoteLst删除多条
		// RegisterDeleteWorkOrderNoteLst(workordernotelst, "/delete", serviceOfWorkOrderNoteLst.Delete)
		// WorkOrderNoteLst查询多条
		RegisterSelectWorkOrderNoteLst(workordernotelst, "/query", serviceOfWorkOrderNoteLst.Select)
		// WorkOrderNoteLst查询一条
		RegisterSelectOneWorkOrderNoteLst(workordernotelst, "/get", serviceOfWorkOrderNoteLst.SelectOne)
		// WorkOrderNoteLst修改一条
		// RegisterUpdateOneWorkOrderNoteLst(workordernotelst, "/updateone", serviceOfWorkOrderNoteLst.UpdateOne)
		// WorkOrderNoteLst修改多条
		// RegisterUpdateWorkOrderNoteLst(workordernotelst, "/update", serviceOfWorkOrderNoteLst.Update)

		// WorkOrderStatus的路由组
		workorderstatus := party.Party("/workorderstatus")
		// WorkOrderStatus的服务实例
		var serviceOfWorkOrderStatus = svr.NewWorkOrderStatusService()
		// WorkOrderStatus插入一条
		// RegisterInsertOneWorkOrderStatus(workorderstatus, "/insertone", serviceOfWorkOrderStatus.InsertOne)
		// WorkOrderStatus插入多条
		// RegisterInsertWorkOrderStatus(workorderstatus, "/insert", serviceOfWorkOrderStatus.Insert)
		// WorkOrderStatus删除一条
		// RegisterDeleteOneWorkOrderStatus(workorderstatus, "/deleteone", serviceOfWorkOrderStatus.DeleteOne)
		// WorkOrderStatus删除多条
		// RegisterDeleteWorkOrderStatus(workorderstatus, "/delete", serviceOfWorkOrderStatus.Delete)
		// WorkOrderStatus查询多条
		RegisterSelectWorkOrderStatus(workorderstatus, "/query", serviceOfWorkOrderStatus.Select)
		// WorkOrderStatus查询一条
		RegisterSelectOneWorkOrderStatus(workorderstatus, "/get", serviceOfWorkOrderStatus.SelectOne)
		// WorkOrderStatus修改一条
		// RegisterUpdateOneWorkOrderStatus(workorderstatus, "/updateone", serviceOfWorkOrderStatus.UpdateOne)
		// WorkOrderStatus修改多条
		// RegisterUpdateWorkOrderStatus(workorderstatus, "/update", serviceOfWorkOrderStatus.Update)
	})
}

/******************************************************************************
 *
 * @Interface Name           : init
 *-----------------------------------------------------------------------------
 *
 * @Description              : 包初始化方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func init() {

	// 注册路由
	RegisterRoutes()
}
